# mallu

This project is a python module for making machine learning workflow easier than ever before.

## Installation

Run the following to install:

'''python
pip install mallu
'''

## Usage

'''python
> import mallu as ml

> from mallu import santa as san

> from mallu import model as mlm

Rull All Machine Learning Classificatin alogorithms at once and see the results

> RunAll(models,data,phase='',scores=None,trained_models = {},use_params=False)

Feature Scale your data OHE_features refers to one hot encoded features. OHE_features are to be listed to avoid them

> FeatureScale(data,OHE_features,scaler='MinMaxScaler')


'''

## About Author

Santo K Thomas, who had completed Post-Graduate Diploma on Data Science and Enginneering from Great Lakes (Great Learning), India

